bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.plates_to_parent
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.plates_to_parent